Processors
==========


These processors are used to process data before and after avatarization.

Table of contents
-----------------
.. autosummary::
   :toctree: avatars
   :template: avatars.processors.rst

   avatars.processors.DatetimeProcessor
   avatars.processors.ExpectedMeanProcessor
   avatars.processors.GeolocationNormalizationProcessor
   avatars.processors.GroupModalitiesProcessor
   avatars.processors.InterRecordBoundedCumulatedDifferenceProcessor
   avatars.processors.InterRecordBoundedRangeDifferenceProcessor
   avatars.processors.InterRecordCumulatedDifferenceProcessor
   avatars.processors.InterRecordRangeDifferenceProcessor
   avatars.processors.PerturbationProcessor
   avatars.processors.ProportionProcessor
   avatars.processors.RelativeDifferenceProcessor
   avatars.processors.ToCategoricalProcessor
